﻿using System;
using System.Drawing;
using System.Windows.Forms;
using DeadPix.Classes;

namespace DeadPix.Forms
{
    public partial class FrmOverlay : Form
    {

        private bool _isDrawing;
        private bool _isLabelRemoved;

        private Rectangle _rect;

        private int _startX;
        private int _startY;

        private readonly int _interval;

        public FrmOverlay(int interval)
        {
            InitializeComponent();
            _interval = interval;
        }

        private void FrmOverlay_MouseMove(object sender, MouseEventArgs e)
        {
            if (_isDrawing)
            {
                if (!_isLabelRemoved)
                {
                    Controls.Remove(lblInfo);
                    _isLabelRemoved = true;
                }
                
                Point p = e.Location;
                int x = Math.Min(_startX, p.X);
                int y = Math.Min(_startY, p.Y);
                int w = Math.Abs(p.X - _startX);
                int h = Math.Abs(p.Y - _startY);
                _rect = new Rectangle(x, y, w, h);

                Invalidate();
            }
            else
            {
                if (!_isLabelRemoved)
                {
                    lblInfo.Location = new Point(e.X + 10, e.Y + 10);
                }
            }
        }

        private void FrmOverlay_KeyPress(object sender, KeyPressEventArgs e)
        {
            Close();
        }

        private void FrmOverlay_MouseDown(object sender, MouseEventArgs e)
        {
            _isDrawing = true;
            _rect = new Rectangle(e.X, e.Y, 0, 0);

            _startX = e.X;
            _startY = e.Y;
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            using (Pen pen = new Pen(Color.Black, 2))
            {
                e.Graphics.DrawRectangle(pen, _rect);
            }
        }

        private void FrmOverlay_MouseUp(object sender, MouseEventArgs e)
        {
            _isDrawing = false;

            Point p = e.Location;
            int x = Math.Min(_startX, p.X);
            int y = Math.Min(_startY, p.Y);
            int w = Math.Abs(p.X - _startX);
            int h = Math.Abs(p.Y - _startY);
            
            FlashContainer fc = new FlashContainer(w, h, x, y, true, _interval);
            new FrmFlasher(fc).Show();
            Close();
        }
    }
}